package guestbook;

import com.opencms.file.*;

import java.io.*;
import java.net.*;
import java.util.*;
import java.util.regex.*;
import javax.servlet.http.*;

/**
 * <p>Title: Guestbook</p>
 * <p>Description: Little helper building a questbook, storing entries in DB</p>
 * <p>Copyright: Freeware - NO WARRANTY</p>
 * <p>Company: Gymnastics Association Bauma, Switzerland</p>
 * @author Cyrill Brunschwiler - BRU
 * @version 1.0
 */

public class Util {
    
    public static void checkText(String text) throws Exception {
        String REGEX   = "[a-zA-Z0-9:.!?_-]+";

        Pattern p = Pattern.compile(REGEX);
        Matcher m = p.matcher(text);

        if (!m.matches())
            throw new Exception("InputValidationException: text does not match: " + REGEX);
    }
    
    public static void checkNames(String name) throws Exception {
        String REGEX   = "[a-zA-Z]+ [a-zA-Z]*";

        Pattern p = Pattern.compile(REGEX);
        Matcher m = p.matcher(name);

        if (!m.matches())
            throw new Exception("InputValidationException: name does not match: " + REGEX);
    }
    
    public static void checkLink(String link) throws Exception {
        String REGEX   = "http(s)?:\\/\\/[a-z]+\\.[a-z]+\\.[a-z]+";

        Pattern p = Pattern.compile(REGEX);
        Matcher m = p.matcher(link);

        if (!m.matches())
            throw new Exception("InputValidationException: link does not match: " + REGEX);
    }
    
    public static void checkEmail(String email) throws Exception {
        String REGEX   = "[a-zA-Z-\\._0-9]+@[a-zA-Z-_0-9]+\\.[a-z]+";

        Pattern p = Pattern.compile(REGEX);
        Matcher m = p.matcher(email);

        if (!m.matches())
            throw new Exception("InputValidationException: email does not match: " + REGEX);    
    }
    
    /**
     * Method to clear the cache
     * 
     * @param cms the actual object
     */
    public static void clearCache(CmsObject cms) {

        // first the element cache
        cms.getOnlineElementCache().clearCache();

        URL u = null;
        String p = ((HttpServletRequest)
                    cms.getRequestContext().getRequest().getOriginalRequest()).getServletPath();
        String s = ((HttpServletRequest)
                    cms.getRequestContext().getRequest().getOriginalRequest()).getServerName();
        try {
            u = new URL("http://" + s + p + "/system/workplace/action/login.html?_clearcache=all");
            URLConnection uc = u.openConnection();
            uc.connect();
            InputStream in = uc.getInputStream();
        }
        catch(MalformedURLException e) {
            System.err.println("Exception1: " +e.getMessage() );
        }
        catch (IOException e) {
            System.err.println("Exception2: " +e.getMessage() );
        }
    }
    
}